summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel Moody <daniel.moody@mongodb.com>2022-09-22 23:47:17 -0500
committerDaniel Moody <daniel.moody@mongodb.com>2022-09-22 23:47:17 -0500
commitea7750d74e6f29836eb15256c754290e4b648298 (patch)
tree12255a1dfd40f210e0f6eb743e814820d239e52e
parente3f5d426440c9b4981989f2f4e394524de73f7ce (diff)
downloadmongo-ea7750d74e6f29836eb15256c754290e4b648298.tar.gz
finished protobuf
-rw-r--r--src/third_party/SConscript4
-rw-r--r--src/third_party/protobuf/SConscript217
-rwxr-xr-xsrc/third_party/protobuf/scripts/host_config.sh9
3 files changed, 226 insertions, 4 deletions
diff --git a/src/third_party/SConscript b/src/third_party/SConscript
index 2014e988ee2..44b376789ee 100644
--- a/src/third_party/SConscript
+++ b/src/third_party/SConscript
@@ -609,3 +609,7 @@ cares_env.SConscript('cares/SConscript', exports={'env': cares_env})
re2_env = env.Clone()
#kmsEnv.InjectThirdParty(libraries=['kms-message'])
re2_env.SConscript('re2/SConscript', exports={'env': re2_env})
+
+protobuf_env = env.Clone()
+#kmsEnv.InjectThirdParty(libraries=['kms-message'])
+protobuf_env.SConscript('protobuf/SConscript', exports={'env': protobuf_env}) \ No newline at end of file
diff --git a/src/third_party/protobuf/SConscript b/src/third_party/protobuf/SConscript
index e69de29bb2d..ee34d95e77f 100644
--- a/src/third_party/protobuf/SConscript
+++ b/src/third_party/protobuf/SConscript
@@ -0,0 +1,217 @@
+Import('env')
+
+protobuf_env = env.Clone()
+
+protobuf_env.Append(
+ CPPDEFINES=[
+ 'HAVE_CONFIG_H',
+ ('HAVE_PTHREAD', '1'),
+ ('HAVE_ZLIB', '1'),
+ ('PIC', '1'),
+ ],
+ CCFLAGS=[
+ '-Wno-sign-compare',
+ '-Wno-overloaded-virtual',
+ '-Wno-stringop-overflow',
+ ])
+
+protobuf_root = protobuf_env.Dir(".").srcnode()
+protobuf_platform = protobuf_root.Dir("platform/${TARGET_OS}_${TARGET_ARCH}")
+protobuf_env.Append(CPPPATH=[
+ protobuf_root.Dir("dist"),
+ protobuf_root.Dir("dist/src"),
+])
+
+libprotobuf_source = [
+ "dist/src/google/protobuf/stubs/bytestream.cc",
+ "dist/src/google/protobuf/stubs/common.cc",
+ "dist/src/google/protobuf/stubs/int128.cc",
+ "dist/src/google/protobuf/io/io_win32.cc",
+ "dist/src/google/protobuf/stubs/status.cc",
+ "dist/src/google/protobuf/stubs/statusor.cc",
+ "dist/src/google/protobuf/stubs/stringpiece.cc",
+ "dist/src/google/protobuf/stubs/stringprintf.cc",
+ "dist/src/google/protobuf/stubs/structurally_valid.cc",
+ "dist/src/google/protobuf/stubs/strutil.cc",
+ "dist/src/google/protobuf/stubs/time.cc",
+ "dist/src/google/protobuf/any_lite.cc",
+ "dist/src/google/protobuf/arena.cc",
+ "dist/src/google/protobuf/arenastring.cc",
+ "dist/src/google/protobuf/generated_enum_util.cc",
+ "dist/src/google/protobuf/extension_set.cc",
+ "dist/src/google/protobuf/generated_message_util.cc",
+ "dist/src/google/protobuf/generated_message_table_driven_lite.cc",
+ "dist/src/google/protobuf/implicit_weak_message.cc",
+ "dist/src/google/protobuf/map.cc",
+ "dist/src/google/protobuf/message_lite.cc",
+ "dist/src/google/protobuf/parse_context.cc",
+ "dist/src/google/protobuf/repeated_field.cc",
+ "dist/src/google/protobuf/wire_format_lite.cc",
+ "dist/src/google/protobuf/io/coded_stream.cc",
+ "dist/src/google/protobuf/io/strtod.cc",
+ "dist/src/google/protobuf/io/zero_copy_stream.cc",
+ "dist/src/google/protobuf/io/zero_copy_stream_impl.cc",
+ "dist/src/google/protobuf/io/zero_copy_stream_impl_lite.cc",
+ "dist/src/google/protobuf/any.pb.cc",
+ "dist/src/google/protobuf/api.pb.cc",
+ "dist/src/google/protobuf/any.cc",
+ "dist/src/google/protobuf/descriptor.cc",
+ "dist/src/google/protobuf/descriptor_database.cc",
+ "dist/src/google/protobuf/descriptor.pb.cc",
+ "dist/src/google/protobuf/duration.pb.cc",
+ "dist/src/google/protobuf/dynamic_message.cc",
+ "dist/src/google/protobuf/empty.pb.cc",
+ "dist/src/google/protobuf/extension_set_heavy.cc",
+ "dist/src/google/protobuf/field_mask.pb.cc",
+ "dist/src/google/protobuf/generated_message_reflection.cc",
+ "dist/src/google/protobuf/generated_message_table_driven.cc",
+ "dist/src/google/protobuf/map_field.cc",
+ "dist/src/google/protobuf/message.cc",
+ "dist/src/google/protobuf/reflection_ops.cc",
+ "dist/src/google/protobuf/service.cc",
+ "dist/src/google/protobuf/source_context.pb.cc",
+ "dist/src/google/protobuf/struct.pb.cc",
+ "dist/src/google/protobuf/stubs/substitute.cc",
+ "dist/src/google/protobuf/text_format.cc",
+ "dist/src/google/protobuf/timestamp.pb.cc",
+ "dist/src/google/protobuf/type.pb.cc",
+ "dist/src/google/protobuf/unknown_field_set.cc",
+ "dist/src/google/protobuf/wire_format.cc",
+ "dist/src/google/protobuf/wrappers.pb.cc",
+ "dist/src/google/protobuf/io/gzip_stream.cc",
+ "dist/src/google/protobuf/io/printer.cc",
+ "dist/src/google/protobuf/io/tokenizer.cc",
+ "dist/src/google/protobuf/compiler/importer.cc",
+ "dist/src/google/protobuf/compiler/parser.cc",
+ "dist/src/google/protobuf/util/delimited_message_util.cc",
+ "dist/src/google/protobuf/util/field_comparator.cc",
+ "dist/src/google/protobuf/util/field_mask_util.cc",
+ "dist/src/google/protobuf/util/internal/datapiece.cc",
+ "dist/src/google/protobuf/util/internal/default_value_objectwriter.cc",
+ "dist/src/google/protobuf/util/internal/error_listener.cc",
+ "dist/src/google/protobuf/util/internal/field_mask_utility.cc",
+ "dist/src/google/protobuf/util/internal/json_escaping.cc",
+ "dist/src/google/protobuf/util/internal/json_objectwriter.cc",
+ "dist/src/google/protobuf/util/internal/json_stream_parser.cc",
+ "dist/src/google/protobuf/util/internal/object_writer.cc",
+ "dist/src/google/protobuf/util/internal/protostream_objectsource.cc",
+ "dist/src/google/protobuf/util/internal/protostream_objectwriter.cc",
+ "dist/src/google/protobuf/util/internal/proto_writer.cc",
+ "dist/src/google/protobuf/util/internal/type_info.cc",
+ "dist/src/google/protobuf/util/internal/type_info_test_helper.cc",
+ "dist/src/google/protobuf/util/internal/utility.cc",
+ "dist/src/google/protobuf/util/json_util.cc",
+ "dist/src/google/protobuf/util/message_differencer.cc",
+ "dist/src/google/protobuf/util/time_util.cc",
+ "dist/src/google/protobuf/util/type_resolver_util.cc",
+]
+
+libprotoc_source = [
+ "dist/src/google/protobuf/compiler/code_generator.cc",
+ "dist/src/google/protobuf/compiler/command_line_interface.cc",
+ "dist/src/google/protobuf/compiler/plugin.cc",
+ "dist/src/google/protobuf/compiler/plugin.pb.cc",
+ "dist/src/google/protobuf/compiler/subprocess.cc",
+ "dist/src/google/protobuf/compiler/zip_writer.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_enum.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_enum_field.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_extension.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_field.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_file.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_generator.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_helpers.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_map_field.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_message.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_message_field.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_padding_optimizer.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_primitive_field.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_service.cc",
+ "dist/src/google/protobuf/compiler/cpp/cpp_string_field.cc",
+ "dist/src/google/protobuf/compiler/java/java_context.cc",
+ "dist/src/google/protobuf/compiler/java/java_enum.cc",
+ "dist/src/google/protobuf/compiler/java/java_enum_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_enum_field.cc",
+ "dist/src/google/protobuf/compiler/java/java_enum_field_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_extension.cc",
+ "dist/src/google/protobuf/compiler/java/java_extension_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_field.cc",
+ "dist/src/google/protobuf/compiler/java/java_file.cc",
+ "dist/src/google/protobuf/compiler/java/java_generator.cc",
+ "dist/src/google/protobuf/compiler/java/java_generator_factory.cc",
+ "dist/src/google/protobuf/compiler/java/java_helpers.cc",
+ "dist/src/google/protobuf/compiler/java/java_map_field.cc",
+ "dist/src/google/protobuf/compiler/java/java_map_field_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_message.cc",
+ "dist/src/google/protobuf/compiler/java/java_message_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_message_builder.cc",
+ "dist/src/google/protobuf/compiler/java/java_message_builder_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_message_field.cc",
+ "dist/src/google/protobuf/compiler/java/java_message_field_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_name_resolver.cc",
+ "dist/src/google/protobuf/compiler/java/java_primitive_field.cc",
+ "dist/src/google/protobuf/compiler/java/java_primitive_field_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_shared_code_generator.cc",
+ "dist/src/google/protobuf/compiler/java/java_service.cc",
+ "dist/src/google/protobuf/compiler/java/java_string_field.cc",
+ "dist/src/google/protobuf/compiler/java/java_string_field_lite.cc",
+ "dist/src/google/protobuf/compiler/java/java_doc_comment.cc",
+ "dist/src/google/protobuf/compiler/js/js_generator.cc",
+ "dist/src/google/protobuf/compiler/js/well_known_types_embed.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_enum.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_enum_field.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_extension.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_field.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_file.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_generator.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_helpers.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_map_field.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_message.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_message_field.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_oneof.cc",
+ "dist/src/google/protobuf/compiler/objectivec/objectivec_primitive_field.cc",
+ "dist/src/google/protobuf/compiler/php/php_generator.cc",
+ "dist/src/google/protobuf/compiler/python/python_generator.cc",
+ "dist/src/google/protobuf/compiler/ruby/ruby_generator.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_doc_comment.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_enum.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_enum_field.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_field_base.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_generator.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_helpers.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_map_field.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_message.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_message_field.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_primitive_field.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_reflection_class.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_repeated_enum_field.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_repeated_message_field.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_repeated_primitive_field.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_source_generator_base.cc",
+ "dist/src/google/protobuf/compiler/csharp/csharp_wrapper_field.cc",
+]
+
+protobuf_env.Library(
+ target='protobuf',
+ source=libprotobuf_source,
+ LIBDEPS=[
+ '$BUILD_DIR/third_party/shim_zlib',
+ ],
+)
+
+protobuf_env.Library(
+ target='protoc',
+ source=libprotoc_source,
+ LIBDEPS=[
+ 'protobuf',
+ ],
+)
+
+protobuf_env.Program(
+ target='protoc',
+ source=['dist/src/google/protobuf/compiler/main.cc'],
+ LIBDEPS=[
+ 'protobuf',
+ 'protoc',
+ ],
+ AIB_COMPONENT='protobuf',
+)
diff --git a/src/third_party/protobuf/scripts/host_config.sh b/src/third_party/protobuf/scripts/host_config.sh
index bb822bb088e..e19510d1bf9 100755
--- a/src/third_party/protobuf/scripts/host_config.sh
+++ b/src/third_party/protobuf/scripts/host_config.sh
@@ -1,5 +1,5 @@
#!/bin/bash
# Configures a cares suitable for use in the mongo server, built on the host machine.
set -euo pipefail
IFS=$'\n\t'
@@ -9,7 +9,7 @@ set -vx
TOOLCHAIN_ROOT=/opt/mongodbtoolchain/v3
PATH="$TOOLCHAIN_ROOT/bin:$PATH"
-DEST_DIR=$(git rev-parse --show-toplevel)/src/third_party/cares
+DEST_DIR=$(git rev-parse --show-toplevel)/src/third_party/protobuf
HOST_OS="$(uname -s|tr A-Z a-z)"
HOST_ARCH="$(uname -m)"
@@ -40,6 +40,7 @@ $SRC_DIR/configure \
CC=$TOOLCHAIN_ROOT/bin/gcc
CXX=$TOOLCHAIN_ROOT/bin/g++
-
-make CC=$CC CXX=$CXX -j16 install
+pushd src
+make CC=$CC CXX=$CXX -j16 protoc V=1
+popd
popd
@@ -1,5 +1,5 @@
#!/bin/bash
-# Configures a cares suitable for use in the mongo server, built on the host machine.
+# Configures a protobuf suitable for use in the mongo server, built on the host machine.
set -euo pipefail
IFS=$'\n\t'